summary refs log tree commit diff
path: root/pkgs/development/haskell-modules/generic-builder.nix
diff options
context:
space:
mode:
authorJohn Ericson <Ericson2314@yahoo.com>2017-12-30 22:58:02 -0500
committerGitHub <noreply@github.com>2017-12-30 22:58:02 -0500
commit4d2b7638173afb4c0f0c12a43654bcff5c9500ab (patch)
tree04068195f42530a34d44a63019ddc9f77654804c /pkgs/development/haskell-modules/generic-builder.nix
parent553fd19e679b68082329fdae40dcfb40c2f72cba (diff)
parenta98e68676dc96e9021d9bb0a9f210ac1a35d368b (diff)
downloadnixlib-4d2b7638173afb4c0f0c12a43654bcff5c9500ab.tar
nixlib-4d2b7638173afb4c0f0c12a43654bcff5c9500ab.tar.gz
nixlib-4d2b7638173afb4c0f0c12a43654bcff5c9500ab.tar.bz2
nixlib-4d2b7638173afb4c0f0c12a43654bcff5c9500ab.tar.lz
nixlib-4d2b7638173afb4c0f0c12a43654bcff5c9500ab.tar.xz
nixlib-4d2b7638173afb4c0f0c12a43654bcff5c9500ab.tar.zst
nixlib-4d2b7638173afb4c0f0c12a43654bcff5c9500ab.zip
Merge pull request #26805 from obsidiansystems/cross-elegant
Make cross compilation elegant
Diffstat (limited to 'pkgs/development/haskell-modules/generic-builder.nix')
-rw-r--r--pkgs/development/haskell-modules/generic-builder.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkgs/development/haskell-modules/generic-builder.nix b/pkgs/development/haskell-modules/generic-builder.nix
index c633310a37a4..c0c8e46fbb07 100644
--- a/pkgs/development/haskell-modules/generic-builder.nix
+++ b/pkgs/development/haskell-modules/generic-builder.nix
@@ -222,8 +222,8 @@ stdenv.mkDerivation ({
     setupCompileFlags="${concatStringsSep " " setupCompileFlags}"
     configureFlags="${concatStringsSep " " defaultConfigureFlags} $configureFlags"
 
-    # nativePkgs defined in stdenv/setup.hs
-    for p in "''${nativePkgs[@]}"; do
+    # host.*Pkgs defined in stdenv/setup.hs
+    for p in "''${pkgsHostHost[@]}" "''${pkgsHostTarget[@]}"; do
       if [ -d "$p/lib/${ghc.name}/package.conf.d" ]; then
         cp -f "$p/lib/${ghc.name}/package.conf.d/"*.conf $packageConfDir/
         continue